==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/pl.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Nieprawidłowe ID Chmury Federacyjnej",
    "Server to server sharing is not enabled on this server" : "Serwer do udostępniania serwera nie jest włączony na tym serwerze",
    "Couldn't establish a federated share." : "Nie udało się ustalić udostępnienia federacyjnego.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Nie udało się ustalić udostępnienia federacyjnego, może być błędne hasło.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Wysłano żądanie Udostępniania Federacyjnego, otrzymasz zaproszenie. Sprawdzaj swoje powiadomienia.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Nie można ustanowić udostępniania federacyjnego. Wygląda na to, że serwer wybrany do udostępnienia jest zbyt stary (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Niedozwolone jest wysyłanie grupowych udostępnień federacyjnych z tego serwera.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Udostępnianie %1$s nie powiodło się, ponieważ ten element został już udostępniony kontu %2$s",
    "Not allowed to create a federated share to the same account" : "Niedozwolone jest tworzenie udziału federacyjnego na tym samym koncie",
    "Federated shares require read permissions" : "Udostępnienia federacyjne wymagają uprawnień do odczytu",
    "File is already shared with %s" : "Plik jest już udostępniony dla %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Udostępnianie %1$s nie powiodło się, nie można odnaleźć %2$s, być może serwer jest nieosiągalny lub używa certyfikatu z podpisem własnym.",
    "Could not find share" : "Nie można znaleźć powiązania",
    "Federated sharing" : "Udostępnianie federacyjne",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Otrzymałeś {share} zdalne udostępnienie od {user} (w imieniu {behalf})",
    "You received {share} as a remote share from {user}" : "Otrzymałeś {share} zdalne udostępnienie od {user}",
    "Accept" : "Akceptuj",
    "Decline" : "Odrzuć",
    "Federated Cloud Sharing" : "Udostępnianie Chmury Federacyjnej",
    "Sharing" : "Udostępnianie",
    "Federated file sharing" : "Udostępnianie federacyjne plików",
    "Provide federated file sharing across servers" : "Zezwól na udostępnianie federacyjne plików na serwerach",
    "Unable to update federated files sharing config" : "Nie można zaktualizować konfiguracji udostępniania federacyjnego plików",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Dostosuj sposób udostępniania między serwerami. Obejmuje to również udostępnianie między ludźmi na tym serwerze, jeśli korzystają z udostępniania federacyjnego.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Zezwalaj ludziom na tym serwerze na wysłanie udostępnień do innych serwerów (opcja ta umożliwia również dostęp WebDAV do udostępnień publicznych)",
    "Allow people on this server to receive shares from other servers" : "Zezwalaj osobom na tym serwerze na otrzymywanie współdzielenia z innych serwerów",
    "Allow people on this server to send shares to groups on other servers" : "Zezwalaj osobom na tym serwerze na wysyłanie współdzielenia do grup na innych serwerach",
    "Allow people on this server to receive group shares from other servers" : "Zezwalaj osobom na tym serwerze na otrzymywanie współdzielenia grupowego z innych serwerów",
    "Search global and public address book for people" : "Przeszukuj globalną i publiczną książkę adresową osób",
    "Allow people to publish their data to a global and public address book" : "Pozwól ludziom publikować swoje dane w globalnej i publicznej książce adresowej",
    "Trusted federation" : "Zaufana federacja",
    "Automatically accept shares from trusted federated accounts and groups by default" : "Automatycznie akceptuj udostępnienia z zaufanych kont federacyjnych i domyślnych grup",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Udostępnij mi poprzez mój ID #Nextcloud Chmury Federacyjnej, zobacz {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Udostępnij mi poprzez mój ID #Nextcloud Chmury Federacyjnej",
    "Cloud ID copied to the clipboard" : "ID chmury skopiowany do schowka",
    "Copy to clipboard" : "Kopiuj do schowka",
    "Clipboard not available. Please copy the cloud ID manually." : "Schowek niedostępny. Skopiuj identyfikator chmury ręcznie.",
    "Copied!" : "Skopiowano!",
    "Federated Cloud" : "Chmura Federacyjna",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Możesz udostępniać każdemu, kto używa serwera Nextcloud lub innych serwerów i usług kompatybilnych z Open Cloud Mesh (OCM). Wystarczy, że wpiszesz ID Chmury Federacyjnej w oknie udostępniania, według przykładu: osoba@chmura.przykładowa.com",
    "Your Federated Cloud ID" : "Twój Federowany identyfikator chmury",
    "Share it so your friends can share files with you:" : "Udostępnij, aby Twoi znajomi mogli udostępniać Tobie pliki:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (dawniej Twitter)",
    "formerly Twitter" : "dawny Twitter",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Dodaj do swojej strony",
    "Share with me via Nextcloud" : "Udostępnij mi za pomocą Nextcloud",
    "HTML Code:" : "Kod HTML:",
    "Cancel" : "Anuluj",
    "Add remote share" : "Dodaj zdalne udostępnienie",
    "Remote share" : "Zdalne udostępnienie",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Czy chcesz dodać zdalne udostępnienie {name} od {owner}@{remote}?",
    "Remote share password" : "Hasło zdalnego udostępnienia",
    "Incoming share could not be processed" : "Nie można przetworzyć przychodzącego udostępnienia",
    "Clipboard is not available" : "Schowek jest niedostępny",
    "Your Federated Cloud ID:" : "Twoje ID Chmury Federacyjnej:",
    "Twitter" : "Twitter",
    "Diaspora" : "Diaspora"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-31.0.9-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/pl.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Nieprawidłowe ID Chmury Federacyjnej",
    "Server to server sharing is not enabled on this server" : "Serwer do udostępniania serwera nie jest włączony na tym serwerze",
    "Couldn't establish a federated share." : "Nie udało się ustalić udostępnienia federacyjnego.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Nie udało się ustalić udostępnienia federacyjnego, może być błędne hasło.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Wysłano żądanie Udostępniania Federacyjnego, otrzymasz zaproszenie. Sprawdzaj swoje powiadomienia.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Nie można ustanowić udostępniania federacyjnego. Wygląda na to, że serwer wybrany do udostępnienia jest zbyt stary (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Niedozwolone jest wysyłanie grupowych udostępnień federacyjnych z tego serwera.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Udostępnianie %1$s nie powiodło się, ponieważ ten element został już udostępniony kontu %2$s",
    "Not allowed to create a federated share to the same account" : "Niedozwolone jest tworzenie udziału federacyjnego na tym samym koncie",
    "Federated shares require read permissions" : "Udostępnienia federacyjne wymagają uprawnień do odczytu",
    "File is already shared with %s" : "Plik jest już udostępniony dla %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Udostępnianie %1$s nie powiodło się, nie można odnaleźć %2$s, być może serwer jest nieosiągalny lub używa certyfikatu z podpisem własnym.",
    "Could not find share" : "Nie można znaleźć powiązania",
    "Federated sharing" : "Udostępnianie federacyjne",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Otrzymałeś {share} zdalne udostępnienie od {user} (w imieniu {behalf})",
    "You received {share} as a remote share from {user}" : "Otrzymałeś {share} zdalne udostępnienie od {user}",
    "Accept" : "Akceptuj",
    "Decline" : "Odrzuć",
    "Federated Cloud Sharing" : "Udostępnianie Chmury Federacyjnej",
    "Sharing" : "Udostępnianie",
    "Federated file sharing" : "Udostępnianie federacyjne plików",
    "Provide federated file sharing across servers" : "Zezwalaj na udostępnianie federacyjne plików na serwerach",
    "Confirm data upload to lookup server" : "Potwierdź przesyłanie danych do serwera wyszukiwania",
    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "Po włączeniu wszystkie właściwości konta (np. adres e-mail) z ustawioną widocznością na \"opublikowana” będą automatycznie synchronizowane i przesyłane do zewnętrznego systemu oraz udostępniane w publicznej, globalnej książce adresowej.",
    "Disable upload" : "Wyłącz przesyłanie",
    "Enable data upload" : "Włącz przesyłanie danych",
    "Confirm querying lookup server" : "Potwierdź zapytania do serwera wyszukiwania",
    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "Po włączeniu pole wyszukiwania podczas udostępniania zostanie wysłane do zewnętrznego systemu, który udostępnia publiczną i globalną książkę adresową.",
    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "Służy do pobierania ID Chmury Federacyjnej, aby ułatwić udostępnianie federacyjne.",
    "Moreover, email addresses of users might be sent to that system in order to verify them." : "Ponadto adresy e-mail użytkowników mogą być wysyłane do tego systemu w celu ich weryfikacji.",
    "Disable querying" : "Wyłącz zapytania",
    "Enable querying" : "Włącz zapytania",
    "Unable to update federated files sharing config" : "Nie można zaktualizować konfiguracji udostępniania federacyjnego plików",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Dostosuj sposób udostępniania między serwerami. Obejmuje to również udostępnianie między ludźmi na tym serwerze, jeśli korzystają z udostępniania federacyjnego.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Zezwalaj ludziom na tym serwerze na wysłanie udostępnień do innych serwerów (opcja ta umożliwia również dostęp WebDAV do udostępnień publicznych)",
    "Allow people on this server to receive shares from other servers" : "Zezwalaj osobom na tym serwerze na otrzymywanie współdzielenia z innych serwerów",
    "Allow people on this server to send shares to groups on other servers" : "Zezwalaj osobom na tym serwerze na wysyłanie współdzielenia do grup na innych serwerach",
    "Allow people on this server to receive group shares from other servers" : "Zezwalaj osobom na tym serwerze na otrzymywanie współdzielenia grupowego z innych serwerów",
    "The lookup server is only available for global scale." : "Serwer wyszukiwania jest dostępny tylko w skali globalnej.",
    "Search global and public address book for people" : "Przeszukuj globalną i publiczną książkę adresową osób",
    "Allow people to publish their data to a global and public address book" : "Pozwól ludziom publikować swoje dane w globalnej i publicznej książce adresowej",
    "Trusted federation" : "Zaufana federacja",
    "Automatically accept shares from trusted federated accounts and groups by default" : "Automatycznie akceptuj udostępnienia z zaufanych kont federacyjnych i domyślnych grup",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Udostępnij mi poprzez mój ID #Nextcloud Chmury Federacyjnej, zobacz {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Udostępnij mi poprzez mój ID #Nextcloud Chmury Federacyjnej",
    "Share with me via Nextcloud" : "Udostępnij mi za pomocą Nextcloud",
    "Cloud ID copied" : "Identyfikator Chmury skopiowany",
    "Copy" : "Skopiuj",
    "Clipboard not available. Please copy the cloud ID manually." : "Schowek niedostępny. Skopiuj identyfikator chmury ręcznie.",
    "Copied!" : "Skopiowano!",
    "Federated Cloud" : "Chmura Federacyjna",
    "You can share with anyone who uses a {productName} server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Możesz udostępniać każdemu, kto korzysta z serwera {productName} lub innych serwerów i usług kompatybilnych z Open Cloud Mesh (OCM)! Wystarczy wpisać ich Federated Cloud ID w oknie dialogowym udostępniania. Wygląda to tak: person@cloud.example.com",
    "Your Federated Cloud ID" : "Twój Federowany identyfikator chmury",
    "Share it so your friends can share files with you:" : "Udostępnij, aby Twoi znajomi mogli udostępniać Tobie pliki:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (dawniej Twitter)",
    "formerly Twitter" : "dawny Twitter",
    "Mastodon" : "Mastodon",
    "Bluesky" : "Bluesky",
    "Add to your website" : "Dodaj do swojej strony",
    "Share with me via {productName}" : "Udostępnij mi przez {productName}",
    "HTML Code:" : "Kod HTML:",
    "Cancel" : "Anuluj",
    "Add remote share" : "Dodaj zdalne udostępnienie",
    "Remote share" : "Zdalne udostępnienie",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Czy chcesz dodać zdalne udostępnienie {name} od {owner}@{remote}?",
    "Remote share password" : "Hasło zdalnego udostępnienia",
    "Incoming share could not be processed" : "Nie można przetworzyć przychodzącego udostępnienia",
    "Cloud ID copied to the clipboard" : "ID chmury skopiowany do schowka",
    "Copy to clipboard" : "Kopiuj do schowka",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Możesz udostępniać każdemu, kto używa serwera Nextcloud lub innych serwerów i usług kompatybilnych z Open Cloud Mesh (OCM). Wystarczy, że wpiszesz ID Chmury Federacyjnej w oknie udostępniania, według przykładu: osoba@chmura.przykładowa.com"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
